@@ -1,4 +1,5 @@
 from typing import List, Optional, Dict, Union
+from importlib.metadata import version
 
 import requests
 
@@ -77,7 +78,10 @@ class AlephAlphaClient:
 
     @property
     def request_headers(self):
-        return {"Authorization": "Bearer " + self.token}
+        return {
+            "Authorization": "Bearer " + self.token,
+            "User-Agent": "Aleph-Alpha-Python-Client-" + version('aleph-alpha-client'),
+        }
 
     def available_models(self):
         """
@@ -158,7 +162,7 @@ class AlephAlphaClient:
                 Check available_models() for available hostings.
 
             maximum_tokens (int, optional, default 64):
-                The maximum number of tokens to be generated. Completion will terminate after the maximum number of tokens is reached. Increase this value to generate longer texts. A text is split into tokens. Usually there are more tokens than words. The summed number of tokens of prompt and maximum_tokens depends on the model (for EleutherAI/gpt-neo-2.7B, it may not exceed 2048 tokens).
+                The maximum number of tokens to be generated. Completion will terminate after the maximum number of tokens is reached. Increase this value to generate longer texts. A text is split into tokens. Usually there are more tokens than words. The summed number of tokens of prompt and maximum_tokens depends on the model (for luminous-base, it may not exceed 2048 tokens).
 
             temperature (float, optional, default 0.0)
                 A higher sampling temperature encourages the model to produce less probable outputs ("be more creative"). Values are expected in a range from 0.0 to 1.0. Try high values (e.g. 0.9) for a more "creative" response and the default 0.0 for a well defined and repeatable answer.
